@@ -118,9 +118,11 @@ impl Producer for BcmChangeBrightnessStateProducer {
     ) -> Result<Option<Packet>, ProducerError> {
         let current_value = match state_manager.get_value(self.state_index) {
             Some(Value::U8(value)) => BcmValue::Single(*value),
-            Some(Value::Rgb(r, g, b, brightness)) => BcmValue::Rgb(*r, *g, *b, *brightness),
-            Some(Value::Rgbw(r, g, b, w, brightness)) => {
-                BcmValue::Rgbw(*r, *g, *b, *w, *brightness)
+            Some(Value::Rgb(r, g, b)) => BcmValue::Rgb(*r, *g, *b),
+            Some(Value::RgbB(r, g, b, brightness)) => BcmValue::RgbB(*r, *g, *b, *brightness),
+            Some(Value::Rgbw(r, g, b, w)) => BcmValue::Rgbw(*r, *g, *b, *w),
+            Some(Value::RgbwB(r, g, b, w, brightness)) => {
+                BcmValue::RgbwB(*r, *g, *b, *w, *brightness)
             }
             _ => return Err(ProducerError::WrongStateType),
         };
@@ -290,9 +292,11 @@ impl Producer for BcmAnimateBrightnessStateProducer {
     ) -> Result<Option<Packet>, ProducerError> {
         let current_value = match state_manager.get_value(self.state_index) {
             Some(Value::U8(value)) => BcmValue::Single(*value),
-            Some(Value::Rgb(r, g, b, brightness)) => BcmValue::Rgb(*r, *g, *b, *brightness),
-            Some(Value::Rgbw(r, g, b, w, brightness)) => {
-                BcmValue::Rgbw(*r, *g, *b, *w, *brightness)
+            Some(Value::Rgb(r, g, b)) => BcmValue::Rgb(*r, *g, *b),
+            Some(Value::RgbB(r, g, b, brightness)) => BcmValue::RgbB(*r, *g, *b, *brightness),
+            Some(Value::Rgbw(r, g, b, w)) => BcmValue::Rgbw(*r, *g, *b, *w),
+            Some(Value::RgbwB(r, g, b, w, brightness)) => {
+                BcmValue::RgbwB(*r, *g, *b, *w, *brightness)
             }
             _ => return Err(ProducerError::WrongStateType),
         };
@@ -360,8 +364,10 @@ impl Serialize for BcmValue {
         match *self {
             BcmValue::Binary(value) => vec![0x00, if value { 0x01 } else { 0x00 }],
             BcmValue::Single(value) => vec![0x01, value],
-            BcmValue::Rgb(r, g, b, brightness) => vec![0x02, r, g, b, brightness],
-            BcmValue::Rgbw(r, g, b, w, brightness) => vec![0x03, r, g, b, w, brightness],
+            BcmValue::Rgb(r, g, b) => vec![0x02, r, g, b],
+            BcmValue::RgbB(r, g, b, brightness) => vec![0x03, r, g, b, brightness],
+            BcmValue::Rgbw(r, g, b, w) => vec![0x04, r, g, b, w],
+            BcmValue::RgbwB(r, g, b, w, brightness) => vec![0x05, r, g, b, w, brightness],
         }
     }
 }
@@ -382,18 +388,34 @@ impl TryDeserialize for BcmValue {
             }
             0x01 => Ok(Box::new(BcmValue::Single(data[1]))),
             0x02 => {
+                if data.len() < 4 {
+                    return Err(ConfigSerializerError::WrongSize);
+                }
+
+                Ok(Box::new(BcmValue::Rgb(data[1], data[2], data[3])))
+            }
+            0x03 => {
                 if data.len() < 5 {
                     return Err(ConfigSerializerError::WrongSize);
                 }
 
-                Ok(Box::new(BcmValue::Rgb(data[1], data[2], data[3], data[4])))
+                Ok(Box::new(BcmValue::RgbB(data[1], data[2], data[3], data[4])))
             }
-            0x03 => {
-                if data.len() < 6 {
+            0x04 => {
+                if data.len() < 5 {
                     return Err(ConfigSerializerError::WrongSize);
                 }
 
                 Ok(Box::new(BcmValue::Rgbw(
+                    data[1], data[2], data[3], data[4],
+                )))
+            }
+            0x05 => {
+                if data.len() < 6 {
+                    return Err(ConfigSerializerError::WrongSize);
+                }
+
+                Ok(Box::new(BcmValue::RgbwB(
                     data[1], data[2], data[3], data[4], data[5],
                 )))
             }
@@ -434,7 +456,6 @@ mod tests {
             0x23,                                                   // value
             0x45,                                                   // value
             0x67,                                                   // value
-            0x89,                                                   // value
         ];
 
         let state_manager = StateManager::new();
@@ -442,7 +463,7 @@ mod tests {
         let producer = BcmChangeBrightnessProducer::new(
             PACKET.device_address,
             0x01,
-            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
+            BcmValue::Rgb(0x23, 0x45, 0x67),
         );
 
         assert_eq!(
@@ -454,19 +475,19 @@ mod tests {
     #[test]
     fn change_brightness_serialize_test() {
         let producer =
-            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67, 0x89));
+            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67));
 
-        let expected_data = vec![0xab, 0xab, 0x01, 0x02, 0x23, 0x45, 0x67, 0x89];
+        let expected_data = vec![0xab, 0xab, 0x01, 0x02, 0x23, 0x45, 0x67];
 
         assert_eq!(producer.serialize(), expected_data);
     }
 
     #[test]
     fn change_brightness_deserialize_test() {
-        let data = vec![0xab, 0xab, 0x01, 0x02, 0x23, 0x45, 0x67, 0x89];
+        let data = vec![0xab, 0xab, 0x01, 0x02, 0x23, 0x45, 0x67];
 
         let producer =
-            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67, 0x89));
+            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67));
 
         assert_eq!(
             BcmChangeBrightnessProducer::try_deserialize(&data),
@@ -497,11 +518,10 @@ mod tests {
             0x23,                                                   // value
             0x45,                                                   // value
             0x67,                                                   // value
-            0x89,                                                   // value
         ];
 
         let mut state_manager = StateManager::new();
-        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67, 0x89));
+        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67));
 
         let producer = BcmChangeBrightnessStateProducer::new(0xabab, 0x01, 0);
 
@@ -563,7 +583,6 @@ mod tests {
             0x23,                                                    // target value
             0x45,                                                    // target value
             0x67,                                                    // target value
-            0x89,                                                    // target value
         ];
 
         let state_manager = StateManager::new();
@@ -572,7 +591,7 @@ mod tests {
             PACKET.device_address,
             0x01,
             0xabab_abab,
-            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
+            BcmValue::Rgb(0x23, 0x45, 0x67),
         );
 
         assert_eq!(
@@ -587,11 +606,11 @@ mod tests {
             0xabab,
             0x01,
             0xabab_abab,
-            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
+            BcmValue::Rgb(0x23, 0x45, 0x67),
         );
 
         let expected_data = vec![
-            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x02, 0x23, 0x45, 0x67, 0x89,
+            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x02, 0x23, 0x45, 0x67,
         ];
 
         assert_eq!(producer.serialize(), expected_data);
@@ -600,14 +619,14 @@ mod tests {
     #[test]
     fn animate_brightness_deserialize_test() {
         let data = vec![
-            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x02, 0x23, 0x45, 0x67, 0x89,
+            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x02, 0x23, 0x45, 0x67,
         ];
 
         let producer = BcmAnimateBrightnessProducer::new(
             0xabab,
             0x01,
             0xabab_abab,
-            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
+            BcmValue::Rgb(0x23, 0x45, 0x67),
         );
 
         assert_eq!(
@@ -643,11 +662,10 @@ mod tests {
             0x23,                                                    // target value
             0x45,                                                    // target value
             0x67,                                                    // target value
-            0x89,                                                    // target value
         ];
 
         let mut state_manager = StateManager::new();
-        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67, 0x89));
+        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67));
 
         let producer = BcmAnimateBrightnessStateProducer::new(0xabab, 0x01, 0xabab_abab, 0);
 
@@ -718,36 +736,72 @@ mod tests {
 
     #[test]
     fn bcm_value_rgb_serialize_test() {
-        let value = BcmValue::Rgb(0xab, 0xab, 0xab, 0xab);
+        let value = BcmValue::Rgb(0xab, 0xab, 0xab);
 
-        let expected_data = vec![0x02, 0xab, 0xab, 0xab, 0xab];
+        let expected_data = vec![0x02, 0xab, 0xab, 0xab];
 
         assert_eq!(value.serialize(), expected_data);
     }
 
     #[test]
     fn bcm_value_rgb_deserialize_test() {
-        let data = vec![0x02, 0xab, 0xab, 0xab, 0xab];
+        let data = vec![0x02, 0xab, 0xab, 0xab];
 
-        let expected_value = Box::new(BcmValue::Rgb(0xab, 0xab, 0xab, 0xab));
+        let expected_value = Box::new(BcmValue::Rgb(0xab, 0xab, 0xab));
+
+        assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
+    }
+
+    #[test]
+    fn bcm_value_rgb_b_serialize_test() {
+        let value = BcmValue::RgbB(0xab, 0xab, 0xab, 0xab);
+
+        let expected_data = vec![0x03, 0xab, 0xab, 0xab, 0xab];
+
+        assert_eq!(value.serialize(), expected_data);
+    }
+
+    #[test]
+    fn bcm_value_rgb_b_deserialize_test() {
+        let data = vec![0x03, 0xab, 0xab, 0xab, 0xab];
+
+        let expected_value = Box::new(BcmValue::RgbB(0xab, 0xab, 0xab, 0xab));
 
         assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
     }
 
     #[test]
     fn bcm_value_rgbw_serialize_test() {
-        let value = BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab, 0xab);
+        let value = BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab);
 
-        let expected_data = vec![0x03, 0xab, 0xab, 0xab, 0xab, 0xab];
+        let expected_data = vec![0x04, 0xab, 0xab, 0xab, 0xab];
 
         assert_eq!(value.serialize(), expected_data);
     }
 
     #[test]
     fn bcm_value_rgbw_deserialize_test() {
-        let data = vec![0x03, 0xab, 0xab, 0xab, 0xab, 0xab];
+        let data = vec![0x04, 0xab, 0xab, 0xab, 0xab];
 
-        let expected_value = Box::new(BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab, 0xab));
+        let expected_value = Box::new(BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab));
+
+        assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
+    }
+
+    #[test]
+    fn bcm_value_rgbw_b_serialize_test() {
+        let value = BcmValue::RgbwB(0xab, 0xab, 0xab, 0xab, 0xab);
+
+        let expected_data = vec![0x05, 0xab, 0xab, 0xab, 0xab, 0xab];
+
+        assert_eq!(value.serialize(), expected_data);
+    }
+
+    #[test]
+    fn bcm_value_rgbw_b_deserialize_test() {
+        let data = vec![0x05, 0xab, 0xab, 0xab, 0xab, 0xab];
+
+        let expected_value = Box::new(BcmValue::RgbwB(0xab, 0xab, 0xab, 0xab, 0xab));
 
         assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
     }
